@@ -16,15 +16,12 @@ from adam.commands.medusa.medusa import Medusa
 from adam.commands.nodetool import NodeTool, NodeToolCommandHelper
 from adam.commands.postgres.postgres import Postgres, PostgresCommandHelper
 from adam.commands.preview_table import PreviewTable
-from adam.commands.processes import Processes
 from adam.commands.reaper.reaper import Reaper, ReaperCommandHelper
 from adam.commands.repair.repair import Repair, RepairCommandHelper
 from adam.commands.report import Report
 from adam.commands.restart import Restart
 from adam.commands.rollout import RollOut
 from adam.commands.show.show import Show, ShowCommandHelper
-from adam.commands.status import Status as StatusCmd
-from adam.commands.storage import Storage
 from adam.commands.user_entry import UserEntry
 from adam.commands.watch import Watch
 from adam.k8s_utils.kube_context import KubeContext
@@ -173,19 +170,6 @@ def preview(kubeconfig: str, config: str, param: list[str], cluster: str, namesp
     run_command(PreviewTable(), kubeconfig, config, param, cluster, namespace, pod, extra_args)
 
 
-@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterOrPodCommandHelper, help='Show process overview from Cassandra nodes.')
-@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
-@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
-@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
-@click.option('--cluster', '-c', required=False, metavar='statefulset', help='Kubernetes statefulset name')
-@click.option('--namespace', '-n', required=False, metavar='namespace', help='Kubernetes namespace')
-@click.option('--pod', '-p', required=False, metavar='pod', help='Kubernetes pod name')
-@click.option('--show', '-s', is_flag=True, help='show output from Cassandra nodes')
-@click.argument('extra_args', nargs=-1, metavar='<cluster|pod>', type=click.UNPROCESSED)
-def processes(kubeconfig: str, config: str, param: list[str], cluster: str, namespace: str, pod: str, show: bool, extra_args):
-    run_command(Processes(), kubeconfig, config, param, cluster, namespace, pod, ('-s',) + extra_args if show else extra_args)
-
-
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ReaperCommandHelper, help='Execute Cassandra Reaper operations.')
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
 @click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
@@ -267,32 +251,6 @@ def show(kubeconfig: str, config: str, param: list[str], cluster: str, namespace
     run_command(Show(), kubeconfig, config, param, cluster, namespace, pod, extra_args)
 
 
-@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterOrPodCommandHelper, help='Show combined nodetool status from Cassandra nodes.')
-@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
-@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
-@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
-@click.option('--cluster', '-c', required=False, metavar='statefulset', help='Kubernetes statefulset name')
-@click.option('--namespace', '-n', required=False, metavar='namespace', help='Kubernetes namespace')
-@click.option('--pod', '-p', required=False, metavar='pod', help='Kubernetes pod name')
-@click.option('--show', '-s', is_flag=True, help='show output from Cassandra nodes')
-@click.argument('extra_args', nargs=-1, metavar='<cluster|pod>', type=click.UNPROCESSED)
-def status(kubeconfig: str, config: str, param: list[str], cluster: str, namespace: str, pod: str, show: bool, extra_args):
-    run_command(StatusCmd(), kubeconfig, config, param, cluster, namespace, pod, ('-s',) + extra_args if show else extra_args)
-
-
-@cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=ClusterOrPodCommandHelper, help='Show storage overview from Cassandra nodes.')
-@click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
-@click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
-@click.option('--param', '-v', multiple=True, metavar='<key>=<value>', help='parameter override')
-@click.option('--cluster', '-c', required=False, metavar='statefulset', help='Kubernetes statefulset name')
-@click.option('--namespace', '-n', required=False, metavar='namespace', help='Kubernetes namespace')
-@click.option('--pod', '-p', required=False, metavar='pod', help='Kubernetes pod name')
-@click.option('--show', '-s', is_flag=True, help='show output from Cassandra nodes')
-@click.argument('extra_args', nargs=-1, metavar='<cluster|pod>', type=click.UNPROCESSED)
-def storage(kubeconfig: str, config: str, param: list[str], cluster: str, namespace: str, pod: str, show: bool, extra_args):
-    run_command(Storage(), kubeconfig, config, param, cluster, namespace, pod, ('-s',) + extra_args if show else extra_args)
-
-
 @cli.command(context_settings=dict(ignore_unknown_options=True, allow_extra_args=True), cls=TearDownCommandHelper, help='Teardown.')
 @click.option('--kubeconfig', '-k', required=False, metavar='path', help='path to kubeconfig file')
 @click.option('--config', default='params.yaml', metavar='path', help='path to kaqing parameters file')
