@@ -2,6 +2,9 @@ import click
 
 from adam.commands.command import Command
 from adam.commands.command_helpers import ClusterCommandHelper
+from adam.commands.show.show_app_actions import ShowAppActions
+from adam.commands.show.show_app_queues import ShowAppQueues
+from adam.commands.show.show_login import ShowLogin
 from .show_params import ShowParams
 from .show_app_id import ShowAppId
 from .show_cassandra_status import ShowCassandraStatus
@@ -41,7 +44,7 @@ class Show(Command):
             return state
 
         if state.in_repl:
-            log(lines_to_tabular([c.help(ReplState()) for c in Show.cmd_list()], separator=':'))
+            log(lines_to_tabular([c.help(ReplState()) for c in Show.cmd_list()], separator='\t'))
 
             return 'command-missing'
         else:
@@ -52,8 +55,8 @@ class Show(Command):
                 Command.display_help()
 
     def cmd_list():
-        return [ShowKubectlCommands(), ShowParams(), ShowProcesses(), ShowRepairs(), ShowStorage(), ShowVersion(),
-                ShowCassandraStatus(), ShowCassandraVersion()]
+        return [ShowAppActions(), ShowAppId(), ShowAppQueues(), ShowLogin(), ShowKubectlCommands(), ShowParams(), ShowProcesses(), ShowRepairs(),
+                ShowStorage(), ShowVersion(), ShowCassandraStatus(), ShowCassandraVersion()]
 
     def completion(self, state: ReplState):
         return super().completion(state)
