@@ -18,7 +18,6 @@ from adam.commands.ls import Ls
 from adam.commands.nodetool import NodeTool
 from adam.commands.postgres.postgres import Postgres
 from adam.commands.preview_table import PreviewTable
-from adam.commands.processes import Processes
 from adam.commands.pwd import Pwd
 from adam.commands.reaper.reaper import Reaper
 from adam.commands.repair.repair import Repair
@@ -29,30 +28,51 @@ from adam.commands.param_set import SetParam
 from adam.commands.show.show import Show
 from adam.commands.show.show_app_actions import ShowAppActions
 from adam.commands.show.show_app_id import ShowAppId
-from adam.commands.status import Status
-from adam.commands.storage import Storage
+from adam.commands.show.show_cassandra_status import ShowCassandraStatus
+from adam.commands.show.show_cassandra_version import ShowCassandraVersion
+from adam.commands.show.show_commands import ShowKubectlCommands
+from adam.commands.show.show_login import ShowLogin
+from adam.commands.show.show_params import ShowParams
+from adam.commands.show.show_processes import ShowProcesses
+from adam.commands.show.show_repairs import ShowRepairs
+from adam.commands.show.show_storage import ShowStorage
+from adam.commands.show.show_version import ShowVersion
 from adam.commands.watch import Watch
 
 class ReplCommands:
     def repl_cmd_list() -> list[Command]:
-        return ReplCommands.app() + [CodeStart(), CodeStop()] + [DeviceApp(), DevicePostgres(), DeviceCass()] + ReplCommands.navigation() + \
-               ReplCommands.cassandra_check() + ReplCommands.cassandra_ops() + ReplCommands.tools() + ReplCommands.exit()
+        cmds: list[Command] = ReplCommands.navigation() + ReplCommands.cassandra_check() + ReplCommands.cassandra_ops() + \
+            ReplCommands.tools() + ReplCommands.app() + ReplCommands.exit()
+
+        # 1. dedup commands
+        deduped = []
+        cs = set()
+        for cmd in cmds:
+            if not cmd.command() in cs:
+                deduped.append(cmd)
+                cs.add(cmd.command())
+        # 2. intermediate commands must be added to the end
+        deduped.extend([Show(), App(), Reaper(), Repair()])
+
+        # Command.print_chain(Command.chain(cmds))
+
+        return cmds
 
     def navigation() -> list[Command]:
-        return [Ls(), PreviewTable(), Cd(), Pwd(), ClipboardCopy(), GetParam(), SetParam()] + Show.cmd_list()
+        return [Ls(), PreviewTable(), DeviceApp(), DevicePostgres(), DeviceCass(), Cd(), Pwd(), ClipboardCopy(),
+                GetParam(), SetParam(), ShowParams(), ShowKubectlCommands(), ShowLogin(), ShowVersion()]
 
     def cassandra_check() -> list[Command]:
-        return [Check(), Issues(), NodeTool(), Processes(), Report(), Status(), Storage()]
+        return [ShowCassandraStatus(), ShowCassandraVersion(), ShowRepairs(), ShowStorage(), ShowProcesses(), Check(), Issues(), NodeTool(), Report()]
 
     def cassandra_ops() -> list[Command]:
         return Medusa.cmd_list() + [Restart(), RollOut(), Watch()] + Reaper.cmd_list() + Repair.cmd_list()
 
     def tools() -> list[Command]:
-        return [Cqlsh(), Postgres(), Bash()]
+        return [Cqlsh(), Postgres(), Bash(), CodeStart(), CodeStop()]
 
     def app() -> list[Command]:
-        return [ShowAppActions(), ShowAppId(), ShowAppQueues(), AppPing(), App(), ]
-        # return [C3Echo(), C3IqCount(), C3()]
+        return [ShowAppActions(), ShowAppId(), ShowAppQueues(), AppPing(), App()]
 
     def exit() -> list[Command]:
         return [Exit()]
\ No newline at end of file
