@@ -4,6 +4,10 @@ import re
 from .idp_login import IdpLogin
 
 class Authenticator:
+    @abstractmethod
+    def name(self) -> str:
+        return None
+
     @abstractmethod
     def authenticate(self, idp_uri: str, app_host: str, username: str, password: str) -> IdpLogin:
         pass
