@@ -1,60 +1,10 @@
 import getpass
-import os
-from pathlib import Path
-import traceback
-from dotenv import load_dotenv
 
-from adam.sso.idp_session import IdpSession
+from .cred_cache import CredCache
+from .idp_session import IdpSession
 from .idp_login import IdpLogin
 from adam.config import Config
-from adam.k8s_utils.kube_context import KubeContext
-from adam.utils import log, log2
-
-class CredCache:
-    # the singleton pattern
-    def __new__(cls, *args, **kwargs):
-        if not hasattr(cls, 'instance'): cls.instance = super(CredCache, cls).__new__(cls)
-
-        return cls.instance
-
-    def __init__(self):
-        if not hasattr(self, 'env_f'):
-            self.dir = f'{Path.home()}/.kaqing'
-            self.env_f = f'{self.dir}/.credentials'
-            load_dotenv(dotenv_path=self.env_f)
-
-    def get_username(self):
-        return self.get('IDP_USERNAME')
-
-    def get_password(self):
-        return self.get('IDP_PASSWORD')
-
-    def get(self, key: str) -> str:
-        return os.getenv(key)
-
-    def cache(self, username: str, password: str = None):
-        if os.path.exists(self.env_f):
-            with open(self.env_f, 'w') as file:
-                try:
-                    file.truncate()
-                except:
-                    if Config().is_debug():
-                        log2(traceback.format_exc())
-                    pass
-
-        updated = []
-        updated.append(f'IDP_USERNAME={username}')
-        if not KubeContext.in_cluster() and password:
-            # do not store password to the .credentials file when in Kubernetes pod
-            updated.append(f'IDP_PASSWORD={password}')
-
-        if updated:
-            if not os.path.exists(self.env_f):
-                os.makedirs(self.dir, exist_ok=True)
-            with open(self.env_f, 'w') as file:
-                file.write('\n'.join(updated))
-
-            Config.debug(f'Cached username: {username}, password: {password}')
+from adam.utils import log
 
 class Idp:
     ctrl_c_entered = False
@@ -65,7 +15,7 @@ class Idp:
 
         return cls.instance
 
-    def login(app_host: str, username: str = None, idp_uri: str = None, forced = False, use_token_from_env = True, use_cached = True) -> IdpLogin:
+    def login(app_host: str, username: str = None, idp_uri: str = None, forced = False, use_token_from_env = True, use_cached_creds = True) -> IdpLogin:
         session: IdpSession = IdpSession.create(username, app_host, app_host, idp_uri=idp_uri)
 
         if use_token_from_env:
@@ -81,8 +31,8 @@ class Idp:
                 if Idp.ctrl_c_entered:
                     Idp.ctrl_c_entered = False
 
-                default_user = CredCache().get_username() if use_cached else None
-                Config.debug(f'User read from cache: {default_user} with use_cached: {use_cached}')
+                default_user = CredCache().get_username() if use_cached_creds else None
+                Config().debug(f'User read from cache: {default_user} with use_cached: {use_cached_creds}')
                 if default_user and default_user != username:
                     session = IdpSession.create(default_user, app_host, app_host)
 
@@ -106,7 +56,7 @@ class Idp:
                 if Idp.ctrl_c_entered:
                     Idp.ctrl_c_entered = False
 
-                default_pass = CredCache().get_password() if use_cached else None
+                default_pass = CredCache().get_password() if use_cached_creds else None
                 if default_pass:
                     if forced:
                         password = default_pass
